@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------
 # mockify/exc.py
 #
-# Copyright (C) 2019 - 2020 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
+# Copyright (C) 2019 - 2021 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
 #
 # This file is part of Mockify library and is released under the terms of the
 # MIT license: http://opensource.org/licenses/mit-license.php.
@@ -14,9 +14,12 @@ import logging
 
 from . import _utils
 
+__all__ = export = _utils.ExportList()  # pylint: disable=invalid-all-format
+
 logger = logging.getLogger('mockify')
 
 
+@export
 class MockifyWarning(Warning):
     """Common base class for Mockify warnings.
 
@@ -24,6 +27,7 @@ class MockifyWarning(Warning):
     """
 
 
+@export
 class UninterestedCallWarning(MockifyWarning):
     """This warning is used to inform about uninterested call being made.
 
@@ -34,6 +38,7 @@ class UninterestedCallWarning(MockifyWarning):
     """
 
 
+@export
 class MockifyError(Exception):
     """Common base class for all Mockify exceptions.
 
@@ -41,6 +46,7 @@ class MockifyError(Exception):
     """
 
 
+@export
 class MockifyAssertion(MockifyError, AssertionError):
     """Common base class for all Mockify assertion errors.
 
@@ -51,6 +57,7 @@ class MockifyAssertion(MockifyError, AssertionError):
     """
 
 
+@export
 class UnexpectedCall(MockifyAssertion):
     """Raised when mock was called with parameters that couldn't been matched
     to any of existing expectations.
@@ -126,6 +133,7 @@ class UnexpectedCall(MockifyAssertion):
         return self._expected_calls
 
 
+@export
 class UnexpectedCallOrder(MockifyAssertion):
     """Raised when mock was called but another one is expected to be called
     before.
@@ -172,6 +180,7 @@ class UnexpectedCallOrder(MockifyAssertion):
         return self._expected_call
 
 
+@export
 class UninterestedCall(MockifyAssertion):
     """Raised when call is made to a mock that has no expectations set.
 
@@ -203,6 +212,7 @@ class UninterestedCall(MockifyAssertion):
         return self._actual_call
 
 
+@export
 class OversaturatedCall(MockifyAssertion):
     """Raised when mock with actions recorded using
     :meth:`mockify.core.Expectation.will_once` was called more times than
@@ -262,6 +272,7 @@ class OversaturatedCall(MockifyAssertion):
         return self._oversaturated_expectation
 
 
+@export
 class Unsatisfied(MockifyAssertion):
     """Raised when unsatisfied expectations are present.
 
