@@ -1,7 +1,7 @@
 # ---------------------------------------------------------------------------
 # tests/unit/test_actions.py
 #
-# Copyright (C) 2019 - 2020 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
+# Copyright (C) 2019 - 2021 Maciej Wiatrzyk <maciej.wiatrzyk@gmail.com>
 #
 # This file is part of Mockify library and is released under the terms of the
 # MIT license: http://opensource.org/licenses/mit-license.php.
@@ -218,8 +218,10 @@ class TestYieldAsync:
         mock = Mock('mock')
         mock.expect_call().will_once(YieldAsync('abc'))
         with satisfied(mock):
+            items = []
             async for item in mock():
-                print(item)
+                items.append(item)
+            assert items == ['a', 'b', 'c']
 
 
 class TestRaiseBase:
